@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cryptohash-conduit
 version: 0.1.1
-id: cryptohash-conduit-0.1.1-4ac10775feb2347dbaf7d3cc1009a7f7
-key: crypt_F9Uwg65I9oG2pFZYdvWvY2
+id: cryptohash-conduit-0.1.1-6b607828fd72a263de0a99a243d6077b
+key: crypt_77uE8Q2g2rm1VacIZxOpEj
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: vincent@snarc.org
@@ -22,12 +22,12 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptohash-conduit-0.1.1
-hs-libraries: HScryptohash-conduit-0.1.1-F9Uwg65I9oG2pFZYdvWvY2
+hs-libraries: HScryptohash-conduit-0.1.1-77uE8Q2g2rm1VacIZxOpEj
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
-    conduit-extra-1.1.11-c734df1add5fd1001eeb71b770cb5cb3
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
     cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
